@@ -446,6 +446,27 @@ class CrudFeatureViewsSetTestCase(APITestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.json()[0]['identifier'], str(feature_destination.identifier))
 
+    @patch('geostore.settings.GEOSTORE_RELATION_CELERY_ASYNC', new_callable=PropertyMock)
+    def test_featurerelation_geojson(self, mocked):
+        mocked.return_value = True
+        crud_view = factories.CrudViewFactory()
+        feature_destination = Feature.objects.create(geom=Point(0, 0, srid=4326), layer=crud_view.layer)
+        intersect_relation = LayerRelation.objects.create(
+            relation_type='distance',
+            origin=self.crud_view.layer,
+            destination=crud_view.layer,
+            settings={"distance": 100}
+        )
+        self.feature.sync_relations(intersect_relation.pk)
+        response = self.client.get(reverse('feature-relation', args=(self.crud_view.layer_id,
+                                                                     self.feature.identifier,
+                                                                     intersect_relation.pk)),
+                                   data={"format": "geojson"})
+
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.json()['features'][0]['properties']['identifier'],
+                         str(feature_destination.identifier))
+
     @patch('geostore.settings.GEOSTORE_RELATION_CELERY_ASYNC', new_callable=PropertyMock)
     def test_relations_featurelist_crud_view_do_not_show(self, mocked):
         mocked.return_value = True
@@ -500,8 +521,17 @@ class CrudFeatureViewsSetTestCase(APITestCase):
                                                          self.feature.identifier,
                                                          layer_rel.pk))
         self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(response.json()['relations']['view_view'], url_relation)
+        self.assertEqual(response.json()['relations'][0]['label'], "view_view")
+        self.assertEqual(response.json()['relations'][0]['url'], url_relation)
+        self.assertEqual(response.json()['relations'][0]['empty'], True)
         self.assertEqual(len(response.json()['relations']), 1)
+        Feature.objects.create(geom=Point(0, 0, srid=4326), layer=crud_view.layer)
+        self.feature.sync_relations(layer_rel.pk)
+        response = self.client.get(reverse('feature-detail',
+                                           args=(self.crud_view.layer_id,
+                                                 self.feature.identifier)),
+                                   format="json")
+        self.assertEqual(response.json()['relations'][0]['empty'], False)
 
     def test_relations_featuredetail_without_celery(self):
         crud_view = factories.CrudViewFactory()
@@ -520,7 +550,8 @@ class CrudFeatureViewsSetTestCase(APITestCase):
                                                          self.feature.identifier,
                                                          layer_rel.pk))
         self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(response.json()['relations']['view_view'], url_relation)
+        self.assertEqual(response.json()['relations'][0]['label'], "view_view")
+        self.assertEqual(response.json()['relations'][0]['url'], url_relation)
         self.assertEqual(len(response.json()['relations']), 1)
 
     def test_relations_featurelist_without_celery(self):
